function [ allDicts, uniqueDisplayMPHs] = plotFigureGAINSPEED(gainsMVSP, gainsFOSP, gainsMVTCS, gainsFOTCS)
% This figure plots the various treadmill speeds as a function of display MPH.  We
%  have four data sets that we are graphing (with error bars)
% Each of the inputs has two rows and n cols.  The top row is the
%  displayMPH and the bottom row is the treadVelocity.  FO=FollowObject,
%  MV=Moving Viewpoint, TCS=Feedback-controlled, SP=Self-propelled
% 
% Returns:
% 
% uniqueDisplayMPHs -- the input speeds of the last dataset processed.  For
%  this study, this set was the same for each, but this assumption should be
%  known.
% 
% allDicts -- Dictionary structure of all data points indexed by the
%  uniqueDisplayMPHs, aka input speed.
%

figure
hold on;
dataSets = [{gainsMVSP} {gainsFOSP} {gainsMVTCS} {gainsFOTCS}];

% Initialize variables for display and storage.
colorText = [{'w'};{'w'};{'k'};{'k'}];
allDicts = [];
lineStyleText = [{':'};{'--'};{':'};{'--'}];
symbol = {'^';'o';'^';'o'};
lineWidths = [2 1 2 1];
dataToPlot = [];
meanDatas = [];

% Cycle through each data set and plot.
for i = 1:length(dataSets)
   data = dataSets{i};
   
   % Make dictionary for use in ranksum test
   dataPointDict = [];
   
   % Group the data set by the displayMPHs
   uniqueDisplayMPHs = unique(data(1,:));
   meanData =[];
   stdData = [];
   % Cycle through the displayMPHs and get the tread vals
   for j = 1:length(uniqueDisplayMPHs)  
      
       % Find all indices for this speed.
      indices = find(data(1,:)==uniqueDisplayMPHs(j));
      
      % Add the data points for this set of speeds to a dictionary
      dataPoints = data(2,indices);
      dataPointDict = [dataPointDict; {num2str(uniqueDisplayMPHs(j))} {dataPoints}];
      
      % Assemble the mean and standard deviation for this speed
      meanData = [meanData; mean(dataPoints)];
      stdData = [stdData; std(data(2,indices))];
   end
   
   % Get handle to error bar so that we can change its display features
   % later.
   ebHandle = errorbar(uniqueDisplayMPHs(2:end) + .05*(i-2), meanData(2:end), stdData(2:end));
   
   set(ebHandle, 'Color', 'k', 'Marker', symbol{i}, 'MarkerSize', 12, 'MarkerFaceColor',colorText{i},'LineStyle',lineStyleText{i}, 'LineWidth', lineWidths(i) );
   allDicts = [allDicts; {dataPointDict}];
end

ylabel('Treadmill Speed (mph)','FontSize',36)
xlabel('Viewpoint or Object Speed (mph)', 'FontSize', 36)
ylim([0 3.5])
xlim([0 3.75])
legend( 'Moving Viewpoint Self-Propelled', 'Follow Object Self-Propelled', 'Moving Viewpoint Feedback-Controlled', 'Follow Object Feedback-Controlled', 'Location', 'NorthWest')
hold on
set(gca, 'FontSize', 20)
line([0 3.5], [0 3.5], 'Color', 'k', 'LineStyle', ':', 'LineWidth', 3)

